==> kubernetes-model-extensions-5.9.0-sources.jar: io/fabric8/kubernetes/api/model/extensions/RollbackConfigBuilder.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class RollbackConfigBuilder extends io.fabric8.kubernetes.api.model.extensions.RollbackConfigFluentImpl<io.fabric8.kubernetes.api.model.extensions.RollbackConfigBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.extensions.RollbackConfig,io.fabric8.kubernetes.api.model.extensions.RollbackConfigBuilder>{
  public RollbackConfigBuilder() {
    this(false);
  }
  public RollbackConfigBuilder(java.lang.Boolean validationEnabled) {
    this(new RollbackConfig(), validationEnabled);
  }
  public RollbackConfigBuilder(io.fabric8.kubernetes.api.model.extensions.RollbackConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public RollbackConfigBuilder(io.fabric8.kubernetes.api.model.extensions.RollbackConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new RollbackConfig(), validationEnabled);
  }
  public RollbackConfigBuilder(io.fabric8.kubernetes.api.model.extensions.RollbackConfigFluent<?> fluent,io.fabric8.kubernetes.api.model.extensions.RollbackConfig instance) {
    this(fluent, instance, false);
  }
  public RollbackConfigBuilder(io.fabric8.kubernetes.api.model.extensions.RollbackConfigFluent<?> fluent,io.fabric8.kubernetes.api.model.extensions.RollbackConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withRevision(instance.getRevision()); 
    this.validationEnabled = validationEnabled; 
  }
  public RollbackConfigBuilder(io.fabric8.kubernetes.api.model.extensions.RollbackConfig instance) {
    this(instance,false);
  }
  public RollbackConfigBuilder(io.fabric8.kubernetes.api.model.extensions.RollbackConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withRevision(instance.getRevision()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.extensions.RollbackConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.extensions.RollbackConfig build() {
    RollbackConfig buildable = new RollbackConfig(fluent.getRevision());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RollbackConfigBuilder that = (RollbackConfigBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-extensions-5.11.2-sources.jar: io/fabric8/kubernetes/api/model/extensions/RollbackConfigBuilder.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class RollbackConfigBuilder extends io.fabric8.kubernetes.api.model.extensions.RollbackConfigFluentImpl<io.fabric8.kubernetes.api.model.extensions.RollbackConfigBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.extensions.RollbackConfig,io.fabric8.kubernetes.api.model.extensions.RollbackConfigBuilder>{
  public RollbackConfigBuilder() {
    this(false);
  }
  public RollbackConfigBuilder(java.lang.Boolean validationEnabled) {
    this(new RollbackConfig(), validationEnabled);
  }
  public RollbackConfigBuilder(io.fabric8.kubernetes.api.model.extensions.RollbackConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public RollbackConfigBuilder(io.fabric8.kubernetes.api.model.extensions.RollbackConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new RollbackConfig(), validationEnabled);
  }
  public RollbackConfigBuilder(io.fabric8.kubernetes.api.model.extensions.RollbackConfigFluent<?> fluent,io.fabric8.kubernetes.api.model.extensions.RollbackConfig instance) {
    this(fluent, instance, false);
  }
  public RollbackConfigBuilder(io.fabric8.kubernetes.api.model.extensions.RollbackConfigFluent<?> fluent,io.fabric8.kubernetes.api.model.extensions.RollbackConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withRevision(instance.getRevision()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public RollbackConfigBuilder(io.fabric8.kubernetes.api.model.extensions.RollbackConfig instance) {
    this(instance,false);
  }
  public RollbackConfigBuilder(io.fabric8.kubernetes.api.model.extensions.RollbackConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withRevision(instance.getRevision()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.extensions.RollbackConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.extensions.RollbackConfig build() {
    RollbackConfig buildable = new RollbackConfig(fluent.getRevision());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RollbackConfigBuilder that = (RollbackConfigBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
